# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test;

BEGIN { plan tests => 1 };

use Sman::IndexVersion;
use Sman::Config;

my $config = new Sman::Config();
my $indexversion = new Sman::IndexVersion( $config );

ok(1); # If we made it this far, we're ok.

